<?php
// Exit if accessed directly
if (!defined('ABSPATH')) exit;
require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
add_filter('plugin_row_meta','innoship_plugin_meta', 10, 2);
function innoship_plugin_meta($meta,$file){
    if (plugin_basename(DBX_INNOSHIP_PLUGIN_FILE) === $file){
        foreach ($meta as $link) {
            if (strpos($link, 'tab=plugin-information') !== false) {
                return $meta;
            }
        } 
        $our_plugin = get_plugin_data(DBX_INNOSHIP_PLUGIN_FILE);
        $meta[] = sprintf(
            '<a href="%s" class="plugin-settings" aria-label="%s" data-title="%s">%s</a>',
            esc_url(admin_url('options-general.php?page=dbx-innoship-settings-page')),
            esc_attr(sprintf(esc_html__('Setari plugin %s','woo-dbx-innoship'), $our_plugin['Name'])),
            esc_attr($our_plugin['Name']),
            esc_html__('Setari Innoship','woo-dbx-innoship')
            );
        $meta[] = sprintf(
            '<a href="%s" class="thickbox open-plugin-details-modal" aria-label="%s" data-title="%s">%s</a>',
            esc_url(admin_url('plugin-install.php?tab=plugin-information&plugin=woocommerce-dbx-innoship&TB_iframe=true&width=600&height=550')),
            esc_attr(sprintf(esc_html__('Mai multe informații despre %s','woo-dbx-innoship'), $our_plugin['Name'])),
            esc_attr($our_plugin['Name']),
            esc_html__('Vezi Detalii','woo-dbx-innoship')
        );    
        $meta[] = sprintf(
            '<a href="%s" target="_blank">%s</a>',
            esc_url('https://dabex.eu/?utm_source=woocommerce&utm_medium='.$our_plugin['TextDomain'].'&utm_campaign="'.get_site_url().'"'),
            esc_html__('Cere Ajutor','woo-dbx-innoship')
            );    
    }
    return $meta;
}
add_filter ('plugins_api', 'innoship_plugin_info', 20, 3);
function innoship_plugin_info( $res, $action, $args ){
	if( 'plugin_information' !== $action ) {
		return false;
	}
	$plugin_slug = 'woocommerce-dbx-innoship'; 
	if( $plugin_slug !== $args->slug ) {
		return false;
	}
	if( false == $remote = get_transient( 'dbx_innoship_update' . $plugin_slug ) ) {
		$remote = wp_remote_get( DBX_INNOSHIP_JSON, array(
			'timeout' => 10,
			'headers' => array(
				'Accept' => 'application/json'
			) )
		);
		if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
			set_transient( 'dbx_innoship_update' . $plugin_slug, $remote, 43200 ); // 12 hours cache
		}
	}
	if( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
		$remote = json_decode( $remote['body'] );
		$res                    = new stdClass();
		$res->name              = $remote->name;
		$res->slug              = $plugin_slug;
		$res->version           = $remote->version;
		$res->tested            = $remote->tested;
		$res->requires          = $remote->requires;
		$res->author            = '<a href="https://dabex.eu">Dabex Agency</a>';
		$res->author_profile    = 'https://dabex.eu';
		$res->download_link     = $remote->download_url;
		$res->trunk             = $remote->download_url;
		$res->requires_php      = $remote->requires_php;
		$res->last_updated      = $remote->last_updated;
		$res->sections          = array(
			'description'               => $remote->sections->description,
			'changelog'                 => $remote->sections->changelog,
			'asistenta_woocommerce'     => $remote->sections->help,
			'screenshots'               => $remote->screenshots
		);
		$res->banners = array(
		    'low'  => $remote->banners->low,
			'high' => $remote->banners->high
		);
		return $res;
	}
	return false;
}
add_filter('site_transient_update_plugins', 'innoship_plugin_update' );
function innoship_plugin_update( $transient ){
    $current_version = get_plugin_data(DBX_INNOSHIP_PLUGIN_FILE)['Version'];
	if ( empty($transient->checked ) ) {
            return $transient;
        }
	if( false == $remote = get_transient( 'dbx_innoship_update' ) ) {
		$remote = wp_remote_get( DBX_INNOSHIP_JSON, array(
			'timeout' => 10,
			'headers' => array(
				'Accept' => 'application/json'
			) )
		);
		if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && !empty( $remote['body'] ) ) {
			set_transient( 'dbx_innoship_update', $remote, 43200 );
		}
	}
	if( $remote ) {
		$remote = json_decode( $remote['body'] );
		if( $remote && version_compare( $current_version, $remote->version, '<' ) && version_compare($remote->requires, get_bloginfo('version'), '<' ) ) {
			$res                = new stdClass();
			$res->slug          = 'woocommerce-dbx-innoship';
			$res->plugin        = 'woocommerce-dbx-innoship/woocommerce-dbx-innoship.php'; 
			$res->new_version   = $remote->version;
			$res->tested        = $remote->tested;
			$res->package       = $remote->download_url;
			$res->requires_php  = $remote->requires_php;
           	$transient->response[$res->plugin] = $res;
           	$transient->checked[$res->plugin] = $remote->version;
           	}
	}
        return $transient;
}
add_action( 'upgrader_process_complete', 'innoship_after_update', 10, 2 );
function innoship_after_update( $upgrader_object, $options ) {
	if ( $options['action'] == 'update' && $options['type'] === 'plugin' )  {
		delete_transient( 'dbx_innoship_update' );
	}
}
register_activation_hook(DBX_INNOSHIP_PLUGIN_FILE, 'create_table_couriers');
function create_table_couriers(){
	global $wpdb;
	$db_table_name = 'innoship_couriers';
    $charset_collate = $wpdb->get_charset_collate();
	if($wpdb->get_var( "show tables like '$db_table_name'" ) != $db_table_name ) {
    $sql = "CREATE TABLE $db_table_name (
            id int(20) DEFAULT NULL,
            name varchar(255) NOT NULL,
            UNIQUE KEY id (id)
        ) $charset_collate;";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );
    }
}
register_activation_hook(DBX_INNOSHIP_PLUGIN_FILE, 'create_table_status');
function create_table_status(){
	global $wpdb;
	$db_table_name = 'innoship_status';
    $charset_collate = $wpdb->get_charset_collate();
	if($wpdb->get_var( "show tables like '$db_table_name'" ) != $db_table_name ) {
    $sql = "CREATE TABLE $db_table_name (
            id int(20) DEFAULT NULL,
            status varchar(255) NOT NULL,
            UNIQUE KEY id (id)
        ) $charset_collate;";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );
    }
}
register_activation_hook(DBX_INNOSHIP_PLUGIN_FILE, 'innoship_insert_courier');
function innoship_insert_courier(){
    global $wpdb;
    $db_table_name = 'innoship_couriers';
    $values = [
        '1'=>'Cargus', 
        '2'=>'DPD', 
        '3' => 'FanCourier', 
        '4' => 'GLS', 
        '5' => 'Nemo', 
        '6' => 'Sameday', 
        '7' => 'ExpressOne', 
        '8' => 'Econt',
        '9' => 'TeamCourier',
        '10' => 'DHL',
        '11' => 'Posta Romana',
        '12' => 'Posta Panduri',
        '13' => 'GLS Hungary',
        '14' => 'DragonStar',
        '15' => 'Coletaria',
        '16' => 'Bookurier',
        '17' => 'Asendia',
        '18' => 'TNT',
        '19' => 'Speedy Bulgaria',
        '20' => 'GLS Croatia',
        '21' => 'GLS Czech Republic', 
        '22' => 'GLS Slovenia', 
        '23' => 'GLS Slovakia', 
        '24' => 'InOut', 
        '25' => 'Stack Courier', 
        '26' => 'Gebruder Weiss', 
        '27' => 'Pallex', 
        '28' => 'Geniki Taxydromiki',
        '29' => 'Courier Manager',
        '30' => 'GLS Italy',
        '31' => 'ECourier',
        '32' => 'Unimasters',
        '33' => 'TCE',
        '34' => 'Transilvania Post',
        '35' => 'Evropat Bulgaria',
        '36' => 'Bulgarian Post',
        '37' => 'SMP Courier',
        '38' => 'DHL Germany',
        '39' => 'Raben',
        '40' => 'Memex'
    ];
    foreach ($values as $key=>$value){
        $wpdb->insert($db_table_name, ['id' => $key, 'name' => $value]);
    }
}
register_activation_hook(DBX_INNOSHIP_PLUGIN_FILE, 'innoship_insert_status');
function innoship_insert_status(){
    global $wpdb;
    $db_table_name = 'innoship_status';
    $values = [
        '1' => 'Nou', 
        '2' => 'Ridicat de curier', 
        '3' => 'În tranzit către depozit.', 
        '10' => 'În depozit curier.', 
        '20' => 'În tranzit între depozit și destinatar.', 
        '30' => 'În curs de livrare.', 
        '31' => 'Adresă destinatar incorectă.', 
        '33' => 'Colet deteriorat.', 
        '34' => 'Livrare întârziată.', 
        '35' => 'Coletul nu a fost livrat.', 
        '36' => 'Destinatarul nu a fost găsit acasă.', 
        '37' => 'Depozit închis la primirea coletului. Se va livra următoarea zi.',
        '38' => 'Coletul este în depozit, statul On Hold.', 
        '39' => 'Redirecționat către o adresă nouă.', 
        '40' => 'Refuzat.', 
        '41' => 'Eroare la scanarea coletului.',
        '42' => 'Livrare programată pentru o altă dată.', 
        '43' => 'Coletul are nevoie de verificări suplimentare de securitate.', 
        '44' => 'Clientul va ridica personal coletul din depozit/office.', 
        '45' => 'Coletul a fost încărcat în locker.', 
        '46' => 'Coletul a stat prea mult în locker.',
        '47' => 'Probleme tehnice locker.', 
        '100' => 'Coletul a fost livrat.', 
        '101' => 'Colet deteriorat/distrus.', 
        '102' => 'Colet pierdut.',
        '103' => 'Livrat parțial.',
        '104' => 'Colet returnat.', 
        '105' => 'Rambursat.', 
        '106' => 'Anulat de expeditor.', 
        '107' => 'Anulat de curier.', 
        '108' => 'Anulat de sistem.', 
        '109' => 'Imposibil de urmărit.', 
        '110' => 'Returnat cu confirmare.'
    ];
    foreach ($values as $key=>$value){
        $wpdb->insert($db_table_name, ['id' => $key, 'status' => $value]);
    }
}
register_deactivation_hook(DBX_INNOSHIP_PLUGIN_FILE, 'dbx_innoship_deactivate');
function dbx_innoship_deactivate(){
	global $wpdb;
	$wpdb->query("DROP TABLE IF EXISTS `innoship_couriers`, `innoship_status`;");
}