<?php
// Check if WooCommerce is active
if (is_woocommerce_active()) {
    function Innoship_Pickup_Shipping_Method(){
        if (!class_exists('Innoship_Pickup_Shipping_Method')) {
            class Innoship_Pickup_Shipping_Method extends WC_Shipping_Method{
                public function __construct(){
                    $this->id                 = 'dbx-innoship-pickup';
                    $this->method_title       = esc_html__('Ridicare Personală', 'woo-dbx-innoship');
                    $this->method_description = esc_html__('Ridicare Personală', 'woo-dbx-innoship');

                    // Availability & Countries
                    $this->availability = 'including';
                    $this->countries = array('RO');

                    $this->init();

                    $this->title = isset($this->settings['title']) ? $this->settings['title'] : esc_html__('Ridicare Personală', 'woo-dbx-innoship');
                }
                function init(){
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
                    //Add PUDO Locations in cart totals
                    add_action('woocommerce_cart_totals_after_shipping', array($this, 'dbx_review_order_after_shipping'), 20);
                    //Add PUDO Locations in review order
                    add_action('woocommerce_review_order_after_shipping', array($this, 'dbx_review_order_after_shipping'), 20);
                }
                function init_form_fields(){
                    $this->form_fields = array(
                        'title' => array(
                            'title' => esc_html__('Denumire metoda livrare *', 'woo-dbx-innoship'),
                            'type' => 'text',
                            'description' => esc_html__('Denumirea metodei de livrare in Cart si Checkout.', 'woo-dbx-innoship'),
                            'default' => esc_html__('Ridicare Personală', 'woo-dbx-innoship'),
                            'desc_tip'      => true,
                            'custom_attributes' => array('required' => 'required')
                        ),
                        'prag_gratis' => array(
                            'title'     => esc_html__('Prag Transport Gratuit', 'woo-dbx-innoship'),
                            'type'      => 'text',
                            'default'   => esc_html__('200', 'woo-dbx-innoship')
                        ),
                        'tarif_implicit' => array(
                            'title'         => esc_html__('Tarif implicit', 'woo-dbx-innoship'),
                            'type'          => 'number',
                            'default'       => esc_html__('17', 'woo-dbx-innoship'),
                            'desc_tip'      => false,
                            'custom_attributes' => array('step' => '0.01', 'min' => '0'),
                        ),
                    );
                }
                public function admin_options(){
                    echo '<h1>Innoship - Setări Ridicare Personală</h1><br/><table class="form-table">';
                    echo '<span>Modalitatea de livrare este valabilă doar pentru livrarea în România.</span>';
                    $this->generate_settings_html();
                    echo '</table>';
                }
                private function fix_format($value){
                    $value = str_replace(',', '.', $value);
                    return $value;
                }
                public function calculate_shipping($package = array()){
                    $prag_gratis        = $this->get_option('prag_gratis');
                    $tarif_implicit = $this->get_option('tarif_implicit');
                    $oras = $package['destination']['city'] ?? '';
                    $postcode = $package['destination']['postcode'] ?? '';
                    $judet = $package['destination']['state'] ?? '';
                    $ramburs = 0;
                    $greutate = 0;
                    foreach ($package['contents'] as $product) {
                        $ramburs += ($product['line_total'] + $product['line_tax']);
                        // WooCommerce 3.0 or later.
                        if (method_exists($product['data'], 'get_height')) {
                            $greutate += $this->fix_format($product['data']->get_weight() ?: 1) * $product['quantity'];
                        } 
                    }
                    $weight_type = get_option('woocommerce_weight_unit');
                    if ($weight_type == 'g') {
                        $greutate = $greutate / 1000;
                    }
                    if ($greutate < 1) {
                        $greutate = 1;
                    } else {
                        $greutate = round($greutate);
                    }
                    $label = $this->title;
                    if ($prag_gratis && ($ramburs >= $prag_gratis)) {
                        $transport = 0;
                        $label .= ': '.esc_html__('Gratuit','woo-dbx-innoship');
                    } 
                    else {
                        $transport = $tarif_implicit;
                        $label = $this->title;
                    }
                    $args = array(
                        'id'    => $this->id,
                        'label' => $label,
                        'cost'  => $transport,
                        'taxes' => true
                    );
                        $this->add_rate($args);
                    
                }
                public function get_innoship_api(){
                    return new InnoshipAPI;
                }
                function dbx_review_order_after_shipping(){
                    if ( did_action( 'woocommerce_cart_totals_after_shipping' ) >= 2 ||
                    did_action( 'woocommerce_review_order_after_shipping' ) >= 2 ) {
                    return;
                    }
                    $settings = (array) get_option( 'dbx-innoship-plugin-settings' );
                    $chosen_shipping_methods = WC()->session->get('chosen_shipping_methods');
                    //var_dump($chosen_shipping_methods);
                    //exit;
                    if (empty($chosen_shipping_methods) || !in_array('dbx-innoship-pickup', $chosen_shipping_methods)) {
                    return;
                    }
                $shipping_city = WC()->session->get('customer')['city'];
                $shipping_county = WC()->session->get('customer')['state'];
                $county = dbx_get_counties($shipping_county);
                $API = $this->get_innoship_api();
                $data = [
                    'LocalityName'          => $shipping_city,
                    'CountyName'            => $county,
                    'CountryCode'           => 'RO',
                    'FixedLocationType'     => '',
                    'ShowInactive'          => 'true',
                    'ExternalLocationId'    => $settings['dbx_innoship_external_location']
                    ];
                $template_data['city']  = $shipping_city;
                $template_data['county']  = $shipping_county;
                $template_data['pudos'] = $API->getFixedLocations($data);
                //var_dump($template_data['pudos']);
                //exit;
                wc_get_template('/templates/checkout-pudo-select.php', $template_data, dirname(__FILE__),  dirname(__FILE__));
                }
            } // end class
        } // end ifclass exist
    } // end function
add_action('woocommerce_shipping_init', 'Innoship_Pickup_Shipping_Method');
} // end if