<?php
// Check if WooCommerce is active
if (is_woocommerce_active()) {
    function Innoship_Shipping_Method(){
        if (!class_exists('Innoship_Shipping_Method')) {
            class Innoship_Shipping_Method extends WC_Shipping_Method{
                public function __construct(){
                    $this->id                 = 'dbx-innoship';
                    $this->method_title       = esc_html__('Livrare Innoship', 'woo-dbx-innoship');
                    $this->method_description = esc_html__('Livrare Innoship', 'woo-dbx-innoship');

                    // Availability & Countries
                    $this->availability = 'including';
                    $this->countries = array('RO');

                    $this->init();

                    $this->title = isset($this->settings['title']) ? $this->settings['title'] : esc_html__('Livrare Innoship', 'woo-dbx-innoship');
                }
                function init(){
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
                }
                function init_form_fields(){
                    $this->form_fields = array(
                        'title' => array(
                            'title' => esc_html__('Denumire metoda livrare *', 'woo-dbx-innoship'),
                            'type' => 'text',
                            'description' => esc_html__('Denumirea metodei de livrare in Cart si Checkout.', 'woo-dbx-innoship'),
                            'default' => esc_html__('Livrare prin Curier', 'woo-dbx-innoship'),
                            'desc_tip'      => true,
                            'custom_attributes' => array('required' => 'required')
                        ),
                        'prag_gratis' => array(
                            'title'     => esc_html__('Prag Transport Gratuit', 'woo-dbx-innoship'),
                            'type'      => 'text',
                            'default'   => esc_html__('200', 'woo-dbx-innoship')
                        ),
                        'tarif_implicit' => array(
                            'title'         => esc_html__('Tarif implicit', 'woo-dbx-innoship'),
                            'type'          => 'number',
                            'default'       => esc_html__('17', 'woo-dbx-innoship'),
                            'desc_tip'      => true,
                            'custom_attributes' => array('step' => '0.01', 'min' => '0'),
                            'description'   => esc_html__('Costul implicit de livrare, pentru comenzile care au o valoare mai mică decât pragul setat mai sus, pentru transport gratuit.', 'woo-dbx-innoship')
                        ),
                    );
                }
                public function admin_options(){
                    echo '<h1>Innoship - Setări Livrare</h1><br/><table class="form-table">';
                    echo '<span>Modalitatea de livrare este valabilă doar pentru livrarea în România.</span>';
                    $this->generate_settings_html();
                    echo '</table>';
                }
                private function fix_format($value){
                    $value = str_replace(',', '.', $value);
                    return $value;
                }
                public function calculate_shipping($package = array()){
                    $prag_gratis        = $this->get_option('prag_gratis');
                    $tarif_implicit = $this->get_option('tarif_implicit');
                    $settings = (array) get_option( 'dbx-innoship-plugin-settings' );
                    $oras = $package['destination']['city'] ?? '';
                    $postcode = $package['destination']['postcode'] ?? '';
                    $judet = $package['destination']['state'] ?? '';
                    $ramburs = 0;
                    $greutate = 0;
                    foreach ($package['contents'] as $product) {
                        $ramburs += ($product['line_total'] + $product['line_tax']);
                        // WooCommerce 3.0 or later.
                        if (method_exists($product['data'], 'get_height')) {
                            $greutate += $this->fix_format($product['data']->get_weight() ?: 1) * $product['quantity'];
                        } 
                    }
                    $weight_type = get_option('woocommerce_weight_unit');
                    if ($weight_type == 'g') {
                        $greutate = $greutate / 1000;
                    }
                    if ($greutate < 1) {
                        $greutate = 1;
                    } else {
                        $greutate = round($greutate);
                    }
                    $label = $this->title;
                    if ($prag_gratis && ($ramburs >= $prag_gratis)) {
                        $transport = 0;
                        $label .= ': '.esc_html__('Gratuit','woo-dbx-innoship');
                    } 
                    else {
                        $transport = $tarif_implicit;
                        $label = $this->title;
                    }
                    $args = array(
                        'id'    => $this->id,
                        'label' => $label,
                        'cost'  => $transport,
                        'taxes' => true
                    );
                        $this->add_rate($args);
                    
                } // end method
            } // end class
        } // end ifclass exist
    } // end function
add_action('woocommerce_shipping_init', 'Innoship_Shipping_Method');
} // end if